@@ -68,7 +68,7 @@ class BaseNet(pl.LightningModule):
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
         """
         super(BaseNet, self).__init__()
-        if isinstance(dims, tuple):
+        if not isinstance(dims, int):
             flattened = 1
             for dim in dims:
                 flattened *= dim
