@@ -76,9 +76,9 @@ def split_data(
             random_state=0
         )
     
-    X_train_tensor = torch.Tensor(X_train).float() if not isinstance(X_train, torch.Tensor) else X_train.float()
+    X_train_tensor = torch.Tensor(X_train).float().reshape(-1, *(X.shape[1:])) if not isinstance(X_train, torch.Tensor) else X_train.float().reshape(-1, *(X.shape[1:]))
     y_train_tensor = torch.Tensor(y_train).float() if not isinstance(y_train, torch.Tensor) else y_train.float()
-    X_val_tensor = torch.Tensor(X_val).float() if not isinstance(X_val, torch.Tensor) else X_val.float()
+    X_val_tensor = torch.Tensor(X_val).float().reshape(-1, *(X.shape[1:])) if not isinstance(X_val, torch.Tensor) else X_val.float().reshape(-1, *(X.shape[1:]))
     y_val_tensor = torch.Tensor(y_val).float() if not isinstance(y_val, torch.Tensor) else y_val.float()
 
     return X_train_tensor, y_train_tensor, X_val_tensor, y_val_tensor, X_predict_tensor, y_predict_tensor, X_test_tensor, y_test_tensor 
